@@ -124,6 +124,7 @@ mod ir_builder {
             rule operation() -> IrAstOperation
                 = op_asm()
                 / op_branch()
+                / op_bitcast()
                 / op_call()
                 / op_cbr()
                 / op_cmp()
@@ -158,6 +159,11 @@ mod ir_builder {
                     )
                 }
 
+            rule op_bitcast() -> IrAstOperation
+                = "bitcast" _ val:id() "to" _ ty:ast_ty() {
+                    IrAstOperation::BitCast(val, ty)
+                }
+
             rule op_branch() -> IrAstOperation
                 = "br" _ to_block:id() {
                     IrAstOperation::Br(to_block)
@@ -311,10 +317,7 @@ mod ir_builder {
 
             rule asm_op_arg_imm() -> Ident
                 = imm:$("i" d:decimal()) {
-                    Ident::new(Span {
-                        span: pest::Span::new(imm.into(), 0, imm.len()).unwrap(),
-                        path: None,
-                    })
+                    Ident::new(Span::new(imm.into(), 0, imm.len(), None).unwrap())
                 }
 
             rule constant() -> IrAstConst
@@ -417,10 +420,7 @@ mod ir_builder {
 
             rule id_id() -> Ident
                 = !ast_ty() id:$(id_char0() id_char()*) _ {
-                    Ident::new(Span {
-                        span: pest::Span::new(id.into(), 0, id.len()).unwrap(),
-                        path: None,
-                    })
+                    Ident::new(Span::new(id.into(), 0, id.len(), None).unwrap())
                 }
 
             rule metadata_decl() -> (MdIdxRef, IrMetadatum)
@@ -532,6 +532,7 @@ mod ir_builder {
             Vec<IrAstAsmOp>,
             Option<MdIdxRef>,
         ),
+        BitCast(String, IrAstTy),
         Br(String),
         Call(String, Vec<String>),
         Cbr(String, String, String),
@@ -836,6 +837,12 @@ mod ir_builder {
                         .ins(context)
                         .asm_block(args, body, return_type, return_name, md_idx)
                 }
+                IrAstOperation::BitCast(val, ty) => {
+                    let to_ty = ty.to_ir_type(context);
+                    block
+                        .ins(context)
+                        .bitcast(*val_map.get(&val).unwrap(), to_ty, opt_ins_md_idx)
+                }
                 IrAstOperation::Br(to_block_name) => {
                     let to_block = named_blocks.get(&to_block_name).unwrap();
                     block.ins(context).branch(*to_block, None, opt_ins_md_idx)
